@@ -19,7 +19,6 @@
 
 #include "caff.h"
 #include "core/images.h"
-#include "core/kgpgkey.h"
 #include "detailedconsole.h"
 #include "gpgproc.h"
 #include "groupedit.h"
@@ -68,11 +67,13 @@
 #include <KContacts/AddresseeList>
 // #include <KContacts/Key> TODO
 #include <KIO/Global>
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KProcess>
-#include <KRun>
 #include <KSelectAction>
 #include <KService>
 #include <KSharedConfig>
@@ -82,10 +83,8 @@
 #include <KStatusNotifierItem>
 #include <KTipDialog>
 #include <KToggleAction>
-#include <KToolInvocation>
 
 #include <QApplication>
-#include <QClipboard>
 #include <QDBusConnection>
 
 #include <QDesktopServices>
@@ -519,6 +518,8 @@ void KeysManager::slotGenerateKey()
 			else
 				gpg_args += QLatin1String(" --gen-key");
 
+			gpg_args += GPGProc::getGpgHomeArguments(gpgbin).join(QLatin1Char(' '));
+
 			QStringList args;
 			args << QLatin1String( "-e" )
 			     << gpg_args;
@@ -1046,8 +1047,10 @@ void KeysManager::slotAddressbookSearchResult(KJob *job)
 
 void KeysManager::slotManpage()
 {
-	KToolInvocation::startServiceByDesktopName(QLatin1String("khelpcenter"),
-            QLatin1String("man:/gpg"), nullptr, nullptr, nullptr, QByteArray(), true);
+	const KService::Ptr helpCenter = KService::serviceByDesktopName(QStringLiteral("org.kde.help"));
+	auto job = new KIO::ApplicationLauncherJob(helpCenter);
+	job->setUrls({QUrl(QStringLiteral("man:/gpg"))});
+	job->start();
 }
 
 void KeysManager::slotTip()
@@ -2729,7 +2732,11 @@ KeysManager::clipEncrypt()
 		QStringList options;
 
 		if (!dialog->getCustomOptions().isEmpty() && KGpgSettings::allowCustomEncryptionOptions())
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 			options = dialog->getCustomOptions().split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+			options = dialog->getCustomOptions().split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
 
 		if (dialog->getUntrusted())
 			encOptions |= KGpgEncrypt::AllowUntrustedEncryption;
@@ -2806,7 +2813,9 @@ KeysManager::slotOpenKeyUrl()
 	url.replace(QLatin1String("$$id16$$"), idLC.right(16));
 	url.replace(QLatin1String("$$fpr$$"), idLC);
 
-	new KRun(QUrl(url), this);
+	auto *job = new KIO::OpenUrlJob(QUrl(url));
+	job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+	job->start();
 }
 
 void
@@ -2820,7 +2829,7 @@ KeysManager::clipDecrypt()
 		return;
 	}
 
-    KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, nullptr);
+	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel,  {});
 	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
 	connect(this, &KeysManager::fontChanged, kgpgtxtedit, &KgpgEditor::slotSetFont);
 	kgpgtxtedit->m_editor->setPlainText(cliptext);
@@ -2838,7 +2847,7 @@ KeysManager::clipSign()
 		return;
 	}
 
-    KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, nullptr);
+        KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, {});
 	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
 	connect(kgpgtxtedit->m_editor, &KgpgTextEdit::verifyFinished, kgpgtxtedit, &KgpgEditor::closeWindow);
 
