@@ -105,7 +105,11 @@ void KGpgExternalActions::slotEncryptionKeySelected()
 		const QString customopts(dialog->getCustomOptions().isEmpty());
 
 		if (!customopts.isEmpty())
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 			opts << customopts.split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+			opts << customopts.split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
 	}
 
 	QStringList keys = dialog->selectedKeys();
@@ -181,7 +185,11 @@ void KGpgExternalActions::startFolderEncode()
 
 	QStringList selec = dialog->selectedKeys();
 	KGpgEncrypt::EncryptOptions encOptions = KGpgEncrypt::DefaultEncryption;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	const QStringList encryptOptions = dialog->getCustomOptions().split(QLatin1Char(' '),  QString::SkipEmptyParts);
+#else
+	const QStringList encryptOptions = dialog->getCustomOptions().split(QLatin1Char(' '),  Qt::SkipEmptyParts);
+#endif
 	if (dialog->getSymmetric()) {
 		selec.clear();
 	} else {
