@@ -15,7 +15,8 @@
 #ifndef KGPGTEXTINTERFACE_H
 #define KGPGTEXTINTERFACE_H
 
-#include <KUrl>
+#include <QObject>
+#include <QUrl>
 
 class KGpgTextInterfacePrivate;
 class QString;
@@ -35,7 +36,7 @@ public:
 	explicit KGpgTextInterface(QObject *parent, const QString &keyID, const QStringList &options);
 	~KGpgTextInterface();
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when all files passed to KgpgSignFile() where processed.
      */
@@ -44,11 +45,9 @@ signals:
 public Q_SLOTS:
     /**
      * Sign file function
-     * @param keyID the signing key ID.
      * @param srcUrl file to sign.
-     * @param options additional gpg options, e.g. "--armor"
      */
-    void signFiles(const KUrl::List &srcUrl);
+    void signFiles(const QList<QUrl> &srcUrl);
 
 private Q_SLOTS:
 	void slotSignFile();
